@@ -139,6 +139,7 @@ class BaseTests(TestCase):
         expected_reply = {
             'json': [
                 'test.json',
+                'test_none_values.json',
                 'test_subfolder_1/test_sub_subfolder_2/test_subfolder_2.json',
                 'test_subfolder_1/test_sub_subfolder_3/test_subfolder_3.json',
                 'test_subfolder_1/test_sub_subfolder_3/test_subfolder_4.json',
@@ -363,13 +364,27 @@ class BaseTests(TestCase):
         self.assertEqual(reply_uppercase, None)
         self.assertEqual(reply_mixed, None)
 
+    def test_type_estimate_none_custom(self):
+        allowed_none_values = {"null", "none"}
+        reply_empty = estimate_type("", allowed_none_values)
+        reply_lowercase = estimate_type("none", allowed_none_values)
+        reply_null = estimate_type("null", allowed_none_values)
+        reply_uppercase = estimate_type("NONE", allowed_none_values)
+        reply_mixed = estimate_type("None", allowed_none_values)
+        self.assertNotEqual(reply_empty, None)
+        self.assertEqual(reply_lowercase, None)
+        self.assertEqual(reply_null, None)
+        self.assertEqual(reply_uppercase, None)
+        self.assertEqual(reply_mixed, None)
+
     def test_parser_init_no_recurse(self):
         expected_config_files_dict = {
             'env': [
                 "test.env"
             ],
             'json': [
-                'test.json'
+                'test.json',
+                'test_none_values.json'
             ],
             'yaml': [
                 'test.yaml'
@@ -407,6 +422,7 @@ class BaseTests(TestCase):
             ],
             'json': [
                 'test.json',
+                'test_none_values.json',
                 'test_subfolder_1/test_sub_subfolder_2/test_subfolder_2.json',
                 'test_subfolder_1/test_sub_subfolder_3/test_subfolder_3.json',
                 'test_subfolder_1/test_sub_subfolder_3/test_subfolder_4.json',
@@ -548,7 +564,8 @@ class BaseTests(TestCase):
                 'test.env'
             ],
             'json': [
-                'test.json'
+                'test.json',
+                'test_none_values.json'
             ],
             'yaml': [
                 'test.yaml'
@@ -1397,3 +1414,24 @@ class BaseTests(TestCase):
             self.assertDictEqual(reply["test_dict"], {'hcl_dict_key': 'hcl_dict_value'})
             self.assertListEqual(reply["test_list"], ['test1', 'test2', 'test3'])
             self.assertDictEqual(reply["test_json"], {"test_json_key": "test_json_value"})
+
+    def test_parser_type_estimate_none(self):
+        parser = ParseIt(
+            config_location=f"{test_files_location}/test_none_values.json")
+        reply = parser.read_all_configuration_variables()
+        self.assertEqual(reply["empty_string"], None)
+        self.assertEqual(reply["none_lower"], None)
+        self.assertEqual(reply["none_upper"], None)
+        self.assertEqual(reply["none_mixed"], None)
+        self.assertEqual(reply["null"], None)
+
+    def test_parser_type_estimate_none_custom(self):
+        parser = ParseIt(
+            config_location=f"{test_files_location}/test_none_values.json",
+            none_values={"null", "none"})
+        reply = parser.read_all_configuration_variables()
+        self.assertNotEqual(reply["empty_string"], None)
+        self.assertEqual(reply["none_lower"], None)
+        self.assertEqual(reply["none_upper"], None)
+        self.assertEqual(reply["none_mixed"], None)
+        self.assertEqual(reply["null"], None)
